==> qlcplus_4.13.1.orig.tar.xz: qlcplus-QLC-_4.13.1/webaccess/src/webaccess_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="171"/>
        <source>Loading project...</source>
        <translation>Lade Projekt...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="207"/>
        <source>Fixture stored and loaded</source>
        <translation>Gerät gespeichert und geladen</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="407"/>
        <source>Username and password are required fields.</source>
        <translation>Benutzername und Passwort sind benötigte Felder.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="413"/>
        <location filename="webaccess.cpp" line="438"/>
        <source>User level has to be a positive integer.</source>
        <translation>Benutzerlevel muss eine positive Ganzzahl sein.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="432"/>
        <source>Username is required.</source>
        <translation>Benutzername wird benötigt.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="450"/>
        <source>Error while saving passwords file.</source>
        <translation>Fehler beim Speichern der Passwortdatei.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="465"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>Die Netzwerkkonfiguration hat sich geändert. Neustarten um die Änderungen anzuwenden.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="484"/>
        <source>Autostart configuration changed</source>
        <translation>Autostart-Konfiguration geändert</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="860"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Assistent wird (zur Zeit) für Webzugriff nicht unterstützt</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="912"/>
        <location filename="webaccess.cpp" line="965"/>
        <source>Page</source>
        <translation>Seite</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1131"/>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1163"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1164"/>
        <source>Fade In</source>
        <translation>Einblenden</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1165"/>
        <source>Fade Out</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1166"/>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1167"/>
        <source>Notes</source>
        <translation>Notizen</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1463"/>
        <source>Load project</source>
        <translation>Lade Projekt</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1465"/>
        <source>Simple Desk</source>
        <translation>Einfache Arbeitsfläche</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1467"/>
        <source>Configuration</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Passthrough</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Lade Gerät</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation>Zugriffslevel</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation>Leerlassen um keine Änderung durchzuführen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation>Nur Virtuelle Konsole</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation>Virtuelle Konsole und Einfache Arbeitsfläche</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation>Alles</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation>Nutzer löschen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation>Neuer Benutzername...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation>Neues Passwort...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation>Benutzername und Passwort sind benötigte Felder.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation>Benutzer hinzufügen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation>Hinweis: Falls nicht mindestens ein Benutzer mit Zugriffslevel &quot;Alles&quot; auf der Liste ist, wird die Authorisierung deaktiviert.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="323"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="332"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="340"/>
        <source>Universes configuration</source>
        <translation>Universen-Einstellungen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="347"/>
        <source>Audio configuration</source>
        <translation>Audio-Einstellungen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="355"/>
        <source>User loaded fixtures</source>
        <translation>Vom Benutzer geladene Geräte</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="364"/>
        <source>Authorized users</source>
        <translation>Authorisierte Benutzer</translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="101"/>
        <source>Network interface: </source>
        <translation>Netzwerk Schnittstelle: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="106"/>
        <source>Access point name (SSID): </source>
        <translation>Name des AccessPoints (SSID): </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="108"/>
        <source>WPA-PSK Password: </source>
        <translation>WPA-PSK Passwort: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="113"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dynamisch (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="115"/>
        <source>Static</source>
        <translation>Statisch</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="119"/>
        <source>IP Address: </source>
        <translation>IP Addresse: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="121"/>
        <source>Netmask: </source>
        <translation>Netzmaske: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="123"/>
        <source>Gateway: </source>
        <translation>Gateway: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="126"/>
        <location filename="webaccessnetwork.cpp" line="344"/>
        <source>Apply changes</source>
        <translation>Änderungen übernehmen</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="327"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="333"/>
        <source>Network configuration</source>
        <translation>Netzwerk-Konfiguration</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="338"/>
        <source>Project autostart</source>
        <translation>Autostart-Projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>No project</source>
        <translation>Kein Projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Use current project</source>
        <translation>Verwende aktutelles Projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Reboot</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="349"/>
        <source>Shutdown</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Seite</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Vorige Seite</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Nächste Seite</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Universum zurücksetzen</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Universum</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.3.orig.tar.xz: qlcplus-QLC-_4.14.3/webaccess/src/webaccess_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="172"/>
        <source>Loading project...</source>
        <translation>Lade Projekt...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="208"/>
        <source>Fixture stored and loaded</source>
        <translation>Gerät gespeichert und geladen</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="408"/>
        <source>Username and password are required fields.</source>
        <translation>Benutzername und Passwort sind benötigte Felder.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="414"/>
        <location filename="webaccess.cpp" line="439"/>
        <source>User level has to be a positive integer.</source>
        <translation>Benutzerlevel muss eine positive Ganzzahl sein.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="433"/>
        <source>Username is required.</source>
        <translation>Benutzername wird benötigt.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="451"/>
        <source>Error while saving passwords file.</source>
        <translation>Fehler beim Speichern der Passwortdatei.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="466"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>Die Netzwerkkonfiguration hat sich geändert. Neustarten um die Änderungen anzuwenden.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="468"/>
        <source>An error occurred while updating the network configuration.</source>
        <translation>Beim Aktualisieren der Netzwerk-Konfiguration ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="484"/>
        <source>Wi-Fi hotspot successfully activated.</source>
        <translation>Der Wi-Fi-Hotspot wurde erfolgreich aktiviert.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="486"/>
        <source>An error occurred while creating a Wi-Fi hotspot.</source>
        <translation>Beim Erstellen des Wi-Fi-Hotspots ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="491"/>
        <source>Wi-Fi hotspot successfully deactivated.</source>
        <translation>Der Wi-Fi-Hotspot wurde erfolgreich deaktiviert.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="507"/>
        <source>Autostart configuration changed</source>
        <translation>Autostart-Konfiguration geändert</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1014"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Assistent wird (zurzeit) für Webzugriff nicht unterstützt</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1440"/>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1643"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1644"/>
        <source>Fade In</source>
        <translation>Einblenden</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1645"/>
        <source>Fade Out</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1646"/>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1647"/>
        <source>Notes</source>
        <translation>Notizen</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2076"/>
        <source>Color 2 Reset</source>
        <translation>Farbe 2-Reset</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2085"/>
        <source>Color 3 Reset</source>
        <translation>Farbe 3-Reset</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2094"/>
        <source>Color 4 Reset</source>
        <translation>Farbe 4-Reset</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2103"/>
        <source>Color 5 Reset</source>
        <translation>Farbe 5-Reset</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2345"/>
        <source>Load project</source>
        <translation>Lade Projekt</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2347"/>
        <source>Simple Desk</source>
        <translation>Einfache Arbeitsfläche</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2349"/>
        <source>Configuration</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Passthrough</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Lade Gerät</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation>Zugriffslevel</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation>Leerlassen um keine Änderung durchzuführen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation>Nur Virtuelle Konsole</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation>Virtuelle Konsole und Einfache Arbeitsfläche</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation>Alles</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation>Ändern</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation>Nutzer löschen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation>Neuer Benutzername...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation>Neues Passwort...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation>Benutzername und Passwort sind benötigte Felder.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation>Benutzer hinzufügen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation>Hinweis: Falls nicht mindestens ein Benutzer mit Zugriffslevel &quot;Alles&quot; auf der Liste ist, wird die Autorisierung deaktiviert.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="322"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="331"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="339"/>
        <source>Universes configuration</source>
        <translation>Universen-Einstellungen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="346"/>
        <source>Audio configuration</source>
        <translation>Audio-Einstellungen</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="354"/>
        <source>User loaded fixtures</source>
        <translation>Vom Benutzer geladene Geräte</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="363"/>
        <source>Authorized users</source>
        <translation>Autorisierte Benutzer</translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="114"/>
        <source>Wi-Fi Hotspot</source>
        <translation>Wi-Fi-Hotspot</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="118"/>
        <location filename="webaccessnetwork.cpp" line="136"/>
        <source>Access point name (SSID): </source>
        <translation>Name des Access-Points (SSID): </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="120"/>
        <location filename="webaccessnetwork.cpp" line="138"/>
        <source>WPA-PSK Password: </source>
        <translation>WPA-PSK Passwort: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="124"/>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="125"/>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="130"/>
        <source>Network interface</source>
        <translation>Netzwerk-Schnittstelle</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="144"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dynamisch (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="146"/>
        <source>Static</source>
        <translation>Statisch</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="151"/>
        <source>IP Address: </source>
        <translation>IP-Adresse: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="153"/>
        <source>Netmask: </source>
        <translation>Netzmaske: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="155"/>
        <source>Gateway: </source>
        <translation>Gateway: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="158"/>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Apply changes</source>
        <translation>Änderungen übernehmen</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="326"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="332"/>
        <source>Network configuration</source>
        <translation>Netzwerk-Konfiguration</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="337"/>
        <source>Project autostart</source>
        <translation>Autostart-Projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="341"/>
        <source>No project</source>
        <translation>Kein Projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>Use current project</source>
        <translation>Verwende aktuelles Projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="347"/>
        <source>Reboot</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Shutdown</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Seite</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Vorige Seite</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Nächste Seite</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Universum zurücksetzen</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Universum</translation>
    </message>
</context>
</TS>
